==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/RemoteAddressMatchConditionParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the parameters for RemoteAddress match conditions
 * @property matchValues Match values to match against. The operator will apply to each value in here with OR semantics. If any of them match the variable with the given operator this match condition is considered a match.
 * @property negateCondition Describes if this is negate condition or not
 * @property operator Describes operator to be matched
 * @property transforms List of transforms
 * @property typeName
 */
public data class RemoteAddressMatchConditionParametersResponse(
    public val matchValues: List<String>? = null,
    public val negateCondition: Boolean? = null,
    public val `operator`: String,
    public val transforms: List<String>? = null,
    public val typeName: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.RemoteAddressMatchConditionParametersResponse):
            RemoteAddressMatchConditionParametersResponse =
            RemoteAddressMatchConditionParametersResponse(
                matchValues = javaType.matchValues().map({ args0 -> args0 }),
                negateCondition = javaType.negateCondition().map({ args0 -> args0 }).orElse(null),
                `operator` = javaType.`operator`(),
                transforms = javaType.transforms().map({ args0 -> args0 }),
                typeName = javaType.typeName(),
            )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/cdn/kotlin/outputs/RemoteAddressMatchConditionParametersResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.cdn.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List

/**
 * Defines the parameters for RemoteAddress match conditions
 * @property matchValues Match values to match against. The operator will apply to each value in here with OR semantics. If any of them match the variable with the given operator this match condition is considered a match.
 * @property negateCondition Describes if this is negate condition or not
 * @property operator Describes operator to be matched
 * @property transforms List of transforms
 * @property typeName
 */
public data class RemoteAddressMatchConditionParametersResponse(
    public val matchValues: List<String>? = null,
    public val negateCondition: Boolean? = null,
    public val `operator`: String,
    public val transforms: List<String>? = null,
    public val typeName: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.cdn.outputs.RemoteAddressMatchConditionParametersResponse): RemoteAddressMatchConditionParametersResponse =
            RemoteAddressMatchConditionParametersResponse(
                matchValues = javaType.matchValues().map({ args0 -> args0 }),
                negateCondition = javaType.negateCondition().map({ args0 -> args0 }).orElse(null),
                `operator` = javaType.`operator`(),
                transforms = javaType.transforms().map({ args0 -> args0 }),
                typeName = javaType.typeName(),
            )
    }
}
